
function xv = triinf(L, b)

%TRIINF Determina la soluzione di un sistema triangolare
% inferiore
%
% Uso:
% xv = triinf(L, b)
%
% Dati di ingresso:
% L: matrice triangolare inferiore quadrata
% b: vettore COLONNA termine noto
%
% Dati di uscita:
% xv: vettore COLONNA contenente la soluzione

% [x] = Tri inf (L, b, n)
% for i = 1, . . . , n
% x(i) = b(i)
% for j = 1 . . . , i ? 1
% x(i) = x(i) ? l(i,j)* x(j)
% end for j
% x(i) = x(i)/l(i,i)
% end for i

n=size(L,1);

for i = 1:n
    xv(i,1) = b(i,1);
    for j = 1 :(i-1)
        xv(i,1) = xv(i,1) - L(i,j)* xv(j,1)
    end
    if abs(L(i,i)) > 0
        xv(i,1) = xv(i,1)/L(i,i);
    else
        xv=zeros(n,1);
        disp('\n \t Warning: la matrice L non e'' singolare');
    end
end
